@@ -22,8 +22,13 @@
 #ifndef _INDENT_H
 #define _INDENT_H
 
+void indent_set_state(gboolean state);
+gboolean indent_get_state(void);
+void indent_real(GtkWidget *text_view);
 void indent_refresh_tab_width(GtkWidget *text_view);
-void indent_change_state(gboolean state);
-void indent_init(GtkWidget *text_view);
+void indent_toggle_tab_width(GtkWidget *text_view);
+void indent_multi_line_indent(GtkTextBuffer *buffer);
+void indent_multi_line_unindent(GtkTextBuffer *buffer);
+//void indent_init(GtkWidget *text_view);
 
 #endif /* _INDENT_H */
