@@ -25,7 +25,7 @@
 //#include "leafpad.h"
 
 MainWindow *create_main_window(StructData *sd);
-gchar *get_current_file_basename(gchar *filepath);
+gchar *get_current_file_basename(gchar *filename);
 void set_main_window_title(StructData *sd);
 //void set_main_window_title_with_asterisk(gboolean flag);
 //void set_main_window_title_toggle_asterisk(void);
